@@ -592,7 +592,8 @@
     (if (not doit)
 	(progn
 	  (mew-elet (insert "\n"))
-	  (mew-mime-part-messages t))
+	  (mew-mime-part-messages t)
+	  (message "Displaying a PDF document...failed"))
       (setq file1 (mew-make-temp-name))
       (with-current-buffer cache
 	(mew-flet
@@ -956,7 +957,7 @@ See 'mew-mime-content-type' to know how actions can be defined."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2012 Mew developing team.
+;; Copyright (C) 1997-2014 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
