@@ -177,6 +177,8 @@
 	      (set-process-filter   pro 'mew-passwd-filter)
 	      (set-process-sentinel pro 'mew-passwd-sentinel)
 	      (mew-passwd-rendezvous)
+	      (unless (file-exists-p tfile)
+		(setq mew-passwd-master nil))
 	      (when mew-passwd-master
 		(let ((coding-system-for-read 'undecided))
 		  (insert-file-contents tfile))
@@ -226,13 +228,12 @@
   (let* ((name (process-name process))
 	 (regex (concat "^" (regexp-quote mew-passwd-encryption-name)))
 	 (encrypt-p (string-match regex name)))
-    (save-excursion
-      (set-buffer (process-buffer process))
+    (with-current-buffer (process-buffer process)
       (cond
        ((string-match "invalid passphrase" string)
 	(mew-warn "Master password mismatch!")
 	(setq mew-passwd-master nil))
-       ((string-match "bad key" string)
+       ((string-match "[bB]ad \\(?:session \\)?key" string)
 	(mew-warn "Master password is wrong!")
 	(setq mew-passwd-master nil))
        ((string-match "Enter passphrase:" string)
@@ -266,7 +267,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2009 Mew developing team.
+;; Copyright (C) 1996-2014 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
